@@ -5,11 +5,10 @@ import sys
 from elasticsearch import Elasticsearch
 import spacy
 
-try:
-    nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
-except:
+if not spacy.util.is_package("es_core_news_md"):
     system("python -m spacy download es_core_news_md")
-    nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
+      
+nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
 
 
 
